<?php
/**
 * Korean language file
 *
 * @license GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Hyun Kim <lawfully@gmail.com>
 * @author jk Lee
 * @author dongnak@gmail.com
 * @author Song Younghwan <purluno@gmail.com>
 * @author Seung-Chul Yoo <dryoo@live.com>
 * @author erial2@gmail.com
 * @author Myeongjin <aranet100@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = '문서 편집';
$lang['btn_source']            = '내용 보기';
$lang['btn_show']              = '문서 보기';
$lang['btn_create']            = '문서 만들기';
$lang['btn_search']            = '찾기';
$lang['btn_save']              = '저장';
$lang['btn_preview']           = '미리 보기';
$lang['btn_top']               = '맨 위로';
$lang['btn_newer']             = '<< 최근';
$lang['btn_older']             = '이전 >>';
$lang['btn_revs']              = '이전 판';
$lang['btn_recent']            = '최근 바뀜';
$lang['btn_upload']            = '올리기';
$lang['btn_cancel']            = '취소';
$lang['btn_index']             = '사이트맵';
$lang['btn_secedit']           = '편집';
$lang['btn_login']             = '로그인';
$lang['btn_logout']            = '로그아웃';
$lang['btn_admin']             = '관리';
$lang['btn_update']            = '바꾸기';
$lang['btn_delete']            = '삭제';
$lang['btn_back']              = '뒤로';
$lang['btn_backlink']          = '백링크';
$lang['btn_backtomedia']       = '미디어 파일 선택으로 돌아가기';
$lang['btn_subscribe']         = '구독 관리';
$lang['btn_profile']           = '개인 정보 바꾸기';
$lang['btn_reset']             = '초기화';
$lang['btn_resendpwd']         = '새 비밀번호 설정';
$lang['btn_draft']             = '문서 초안 편집';
$lang['btn_recover']           = '문서 초안 되돌리기';
$lang['btn_draftdel']          = '문서 초안 삭제';
$lang['btn_revert']            = '되돌리기';
$lang['btn_register']          = '등록';
$lang['btn_apply']             = '적용';
$lang['btn_media']             = '미디어 관리';
$lang['loggedinas']            = '다음 사용자로 로그인';
$lang['user']                  = '사용자 이름';
$lang['pass']                  = '비밀번호';
$lang['newpass']               = '새 비밀번호';
$lang['oldpass']               = '현재 비밀번호 확인';
$lang['passchk']               = '비밀번호 다시 확인';
$lang['remember']              = '기억하기';
$lang['fullname']              = '실제 이름';
$lang['email']                 = '이메일';
$lang['profile']               = '개인 정보';
$lang['badlogin']              = '사용자 이름이거나 비밀번호가 잘못되었습니다.';
$lang['minoredit']             = '사소한 바뀜';
$lang['draftdate']             = '문서 초안 자동 저장 시간';
$lang['nosecedit']             = '한동안 문서가 바뀌어 세션 정보의 유효 시간이 지나 문서 전부를 다시 읽습니다.';
$lang['regmissing']            = '모든 항목을 입력해야 합니다.';
$lang['reguexists']            = '같은 이름을 사용하는 사용자가 있습니다.';
$lang['regsuccess']            = '사용자를 만들었으며 비밀번호는 이메일로 보냈습니다.';
$lang['regsuccess2']           = '사용자를 만들었습니다.';
$lang['regmailfail']           = '비밀번호를 이메일로 보낼 때 오류가 발생했습니다. 관리자에게 문의하시기 바랍니다!';
$lang['regbadmail']            = '이메일 주소가 잘못됐습니다 - 오류라고 생각하면 관리자에게 문의하시기 바랍니다';
$lang['regbadpass']            = '새 비밀번호가 일치하지 않습니다. 다시 입력하세요.';
$lang['regpwmail']             = 'DokuWiki 비밀번호';
$lang['reghere']               = '계정이 없나요? 계정을 등록할 수 있습니다';
$lang['profna']                = '이 위키는 개인 정보 수정을 할 수 없습니다';
$lang['profnochange']          = '바뀜이 없습니다.';
$lang['profnoempty']           = '이름이나 이메일 주소가 비었습니다.';
$lang['profchanged']           = '개인 정보가 성공적으로 바뀌었습니다.';
$lang['pwdforget']             = '비밀번호를 잊으셨나요? 비밀번호를 재설정할 수 있습니다';
$lang['resendna']              = '이 위키는 비밀번호 재설정을 지원하지 않습니다.';
$lang['resendpwd']             = '다음으로 새 비밀번호 보내기';
$lang['resendpwdmissing']      = '모든 비밀번호를 입력해야 합니다.';
$lang['resendpwdnouser']       = '등록된 사용자가 아닙니다.';
$lang['resendpwdbadauth']      = '인증 코드가 잘못됐습니다. 잘못된 링크인지 확인하시기 바랍니다.';
$lang['resendpwdconfirm']      = '확인 링크를 이메일로 보냈습니다.';
$lang['resendpwdsuccess']      = '새로운 비밀번호를 이메일로 보냈습니다.';
$lang['license']               = '별도로 라이선스를 알리지 않을 경우, 이 위키의 내용은 다음의 라이선스에 따릅니다:';
$lang['licenseok']             = '참고: 이 문서를 편집할 경우 다음의 라이선스에 동의함을 의미합니다:';
$lang['searchmedia']           = '파일 이름 찾기:';
$lang['searchmedia_in']        = '%s에서 찾기';
$lang['txt_upload']            = '올릴 파일 선택';
$lang['txt_filename']          = '올릴 파일 이름 입력 (선택 사항)';
$lang['txt_overwrt']           = '기존 파일에 덮어쓰기';
$lang['maxuploadsize']         = '최대 올리기 용량입니다. 파일당 %s입니다.';
$lang['lockedby']              = '현재 잠겨진 사용자';
$lang['lockexpire']            = '잠금 해제 시간';
$lang['js']['willexpire']      = '잠시 후 편집 잠금이 해제됩니다.\n편집 충돌을 피하려면 미리 보기를 눌러 잠금 시간을 다시 설정하세요.';
$lang['js']['notsavedyet']     = '저장하지 않은 바뀜이 지워집니다.';
$lang['js']['searchmedia']     = '파일 찾기';
$lang['js']['keepopen']        = '선택할 때 창을 열어 놓기';
$lang['js']['hidedetails']     = '자세한 정보 숨기기';
$lang['js']['mediatitle']      = '링크 설정';
$lang['js']['mediadisplay']    = '링크 형태';
$lang['js']['mediaalign']      = '배치';
$lang['js']['mediasize']       = '그림 크기';
$lang['js']['mediatarget']     = '링크 목표';
$lang['js']['mediaclose']      = '닫기';
$lang['js']['mediainsert']     = '삽입';
$lang['js']['mediadisplayimg'] = '그림을 보여줍니다.';
$lang['js']['mediadisplaylnk'] = '링크만 보여줍니다.';
$lang['js']['mediasmall']      = '작게';
$lang['js']['mediamedium']     = '중간';
$lang['js']['medialarge']      = '크게';
$lang['js']['mediaoriginal']   = '원본';
$lang['js']['medialnk']        = '자세한 정보 문서로 링크';
$lang['js']['mediadirect']     = '원본으로 직접 링크';
$lang['js']['medianolnk']      = '링크 없음';
$lang['js']['medianolink']     = '그림을 링크하지 않음';
$lang['js']['medialeft']       = '왼쪽 배치';
$lang['js']['mediaright']      = '오른쪽 배치';
$lang['js']['mediacenter']     = '가운데 배치';
$lang['js']['medianoalign']    = '배치 없음';
$lang['js']['nosmblinks']      = '윈도우 공유 파일과의 연결은 마이크로소프트 인터넷 익스플로러에서만 동작합니다.\n그러나 링크를 복사하거나 붙여넣기를 할 수 있습니다.';
$lang['js']['linkwiz']         = '링크 마법사';
$lang['js']['linkto']          = '다음으로 연결:';
$lang['js']['del_confirm']     = '정말 선택된 항목을 삭제하겠습니까?';
$lang['js']['restore_confirm'] = '정말 이 판으로 되돌리겠습니까?';
$lang['js']['media_diff']      = '차이 보기:';
$lang['js']['media_diff_both'] = '나란히 보기';
$lang['js']['media_diff_opacity'] = '겹쳐 보기';
$lang['js']['media_diff_portions'] = '쪼개 보기';
$lang['js']['media_select']    = '파일 선택…';
$lang['js']['media_upload_btn'] = '올리기';
$lang['js']['media_done_btn']  = '완료';
$lang['js']['media_drop']      = '올릴 파일을 끌어넣으세요';
$lang['js']['media_cancel']    = '삭제';
$lang['js']['media_overwrt']   = '기존 파일에 덮어쓰기';
$lang['rssfailed']             = '이 피드를 가져오는 동안 오류가 발생했습니다:';
$lang['nothingfound']          = '아무 것도 없습니다.';
$lang['mediaselect']           = '미디어 파일 선택';
$lang['fileupload']            = '미디어 파일 올리기';
$lang['uploadsucc']            = '올리기 성공';
$lang['uploadfail']            = '올리기를 실패했습니다. 잘못된 권한 때문일지도 모릅니다.';
$lang['uploadwrong']           = '올리기를 거부했습니다. 금지된 파일 확장자입니다!';
$lang['uploadexist']           = '파일이 이미 존재합니다.';
$lang['uploadbadcontent']      = '올린 파일이 %s 파일 확장자와 일치하지 않습니다.';
$lang['uploadspam']            = '스팸 차단 목록이 올리기를 취소했습니다.';
$lang['uploadxss']             = '악성 코드의 가능성이 있어 올리기를 취소했습니다.';
$lang['uploadsize']            = '올린 파일이 너무 큽니다. (최대 %s)';
$lang['deletesucc']            = '"%s" 파일이 삭제되었습니다.';
$lang['deletefail']            = '"%s" 파일을 삭제할 수 없습니다 - 삭제 권한이 있는지 확인하세요.';
$lang['mediainuse']            = '"%s" 파일을 삭제할 수 없습니다 - 아직 사용 중입니다.';
$lang['namespaces']            = '이름공간';
$lang['mediafiles']            = '사용 가능한 파일 목록';
$lang['accessdenied']          = '이 문서를 볼 권한이 없습니다.';
$lang['mediausage']            = '이 파일을 참고하려면 다음 문법을 사용하세요:';
$lang['mediaview']             = '원본 파일 보기';
$lang['mediaroot']             = '루트 (root)';
$lang['mediaupload']           = '파일을 현재 이름공간으로 올립니다. 하위 이름공간으로 만들려면 선택한 파일 이름 앞에 쌍점(:)으로 구분되는 이름을 붙이면 됩니다. 파일을 드래그 앤 드롭하여 선택할 수 있습니다.';
$lang['mediaextchange']        = '파일 확장자가 .%s에서 .%s(으)로 바뀌었습니다!';
$lang['reference']             = '참고';
$lang['ref_inuse']             = '다음 문서에서 아직 사용 중이므로 파일을 삭제할 수 없습니다:';
$lang['ref_hidden']            = '문서의 일부 참고는 읽을 수 있는 권한이 없습니다';
$lang['hits']                  = '조회 수';
$lang['quickhits']             = '일치하는 문서 이름';
$lang['toc']                   = '목차';
$lang['current']               = '현재';
$lang['yours']                 = '판';
$lang['diff']                  = '현재 판과의 차이 보기';
$lang['diff2']                 = '선택한 판 사이의 차이 보기';
$lang['difflink']              = '차이 보기로 링크';
$lang['diff_type']             = '차이 보기:';
$lang['diff_inline']           = '인라인 방식';
$lang['diff_side']             = '다중 창 방식';
$lang['line']                  = '줄';
$lang['breadcrumb']            = '추적';
$lang['youarehere']            = '현재 위치';
$lang['lastmod']               = '마지막으로 수정함';
$lang['by']                    = '작성자';
$lang['deleted']               = '삭제함';
$lang['created']               = '새로 만듦';
$lang['restored']              = '이전 판으로 되돌림 (%s)';
$lang['external_edit']         = '바깥 편집기';
$lang['summary']               = '편집 요약';
$lang['noflash']               = '이 콘텐츠를 표시하기 위해서 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash 플러그인</a>이 필요합니다.';
$lang['download']              = '조각 다운로드';
$lang['tools']                 = '도구';
$lang['user_tools']            = '사용자 도구';
$lang['site_tools']            = '사이트 도구';
$lang['page_tools']            = '문서 도구';
$lang['skip_to_content']       = '콘텐츠 넘기기';
$lang['sidebar']               = '사이드바';
$lang['mail_newpage']          = '문서 추가함:';
$lang['mail_changed']          = '문서 바뀜:';
$lang['mail_subscribe_list']   = '이름공간에서 바뀐 문서:';
$lang['mail_new_user']         = '새 사용자:';
$lang['mail_upload']           = '파일 올림:';
$lang['changes_type']          = '차이 보기';
$lang['pages_changes']         = '문서';
$lang['media_changes']         = '미디어 파일';
$lang['both_changes']          = '문서와 미디어 파일 모두';
$lang['qb_bold']               = '굵은 글씨';
$lang['qb_italic']             = '기울인 글씨';
$lang['qb_underl']             = '밑줄 그어진 글씨';
$lang['qb_code']               = '코드 글씨';
$lang['qb_strike']             = '취소선 글씨';
$lang['qb_h1']                 = '1단계 문단 제목';
$lang['qb_h2']                 = '2단계 문단 제목';
$lang['qb_h3']                 = '3단계 문단 제목';
$lang['qb_h4']                 = '4단계 문단 제목';
$lang['qb_h5']                 = '5단계 문단 제목';
$lang['qb_h']                  = '문단 제목';
$lang['qb_hs']                 = '문단 제목 선택';
$lang['qb_hplus']              = '상위 문단 제목';
$lang['qb_hminus']             = '하위 문단 제목';
$lang['qb_hequal']             = '동급 문단 제목';
$lang['qb_link']               = '내부 링크';
$lang['qb_extlink']            = '바깥 링크';
$lang['qb_hr']                 = '가로줄';
$lang['qb_ol']                 = '순서 있는 목록';
$lang['qb_ul']                 = '순서 없는 목록';
$lang['qb_media']              = '그림과 기타 파일 추가';
$lang['qb_sig']                = '서명 넣기';
$lang['qb_smileys']            = '이모티콘';
$lang['qb_chars']              = '특수 문자';
$lang['upperns']               = '상위 이름공간으로 이동';
$lang['admin_register']        = '새 사용자 추가';
$lang['metaedit']              = '메타 데이터 편집';
$lang['metasaveerr']           = '메타 데이터 쓰기 실패';
$lang['metasaveok']            = '메타 데이타 저장됨';
$lang['img_backto']            = '뒤로';
$lang['img_title']             = '이름';
$lang['img_caption']           = '설명';
$lang['img_date']              = '날짜';
$lang['img_fname']             = '파일 이름';
$lang['img_fsize']             = '크기';
$lang['img_artist']            = '만든이';
$lang['img_copyr']             = '저작권';
$lang['img_format']            = '포맷';
$lang['img_camera']            = '카메라';
$lang['img_keywords']          = '키워드';
$lang['img_width']             = '너비';
$lang['img_height']            = '높이';
$lang['img_manager']           = '미디어 관리자에서 보기';
$lang['subscr_subscribe_success'] = '%s 사용자가 %s 구독 목록에 추가했습니다';
$lang['subscr_subscribe_error'] = '%s 사용자가 %s 구독 목록에 추가하는데 실패했습니다';
$lang['subscr_subscribe_noaddress'] = '로그인으로 연결된 주소가 없기 때문에 구독 목록에 추가할 수 없습니다';
$lang['subscr_unsubscribe_success'] = '%s 사용자가 %s 구독 목록에서 삭제했습니다';
$lang['subscr_unsubscribe_error'] = '%s 사용자가 %s 구독 목록에서 삭제하는데 실패했습니다';
$lang['subscr_already_subscribed'] = '%s 사용자가 이미 %s에 구독하고 있습니다';
$lang['subscr_not_subscribed'] = '%s 사용자가 %s에 구독하고 있지 않습니다';
$lang['subscr_m_not_subscribed'] = '현재의 문서나 이름공간에 구독하고 있지 않습니다.';
$lang['subscr_m_new_header']   = '구독 추가';
$lang['subscr_m_current_header'] = '현재 구독 중인 문서';
$lang['subscr_m_unsubscribe']  = '구독 취소';
$lang['subscr_m_subscribe']    = '구독';
$lang['subscr_m_receive']      = '받기';
$lang['subscr_style_every']    = '모든 바뀜을 이메일로 받기';
$lang['subscr_style_digest']   = '각 문서의 바뀜을 요약 (매 %.2f일 마다)';
$lang['subscr_style_list']     = '마지막 이메일 이후 바뀐 문서의 목록 (매 %.2f일 마다)';
$lang['authmodfailed']         = '잘못된 사용자 인증 설정입니다. 관리자에게 문의하시기 바랍니다.';
$lang['authtempfail']          = '사용자 인증이 일시적으로 불가능합니다. 만일 계속해서 문제가 발생하면 관리자에게 문의하시기 바랍니다.';
$lang['authpwdexpire']         = '비밀번호를 바꾼지 %d일이 지났습니다. 비민번호를 곧 바꿔야 합니다.';
$lang['i_chooselang']          = '사용할 언어를 선택하세요';
$lang['i_installer']           = 'DokuWiki 설치';
$lang['i_wikiname']            = '위키 이름';
$lang['i_enableacl']           = 'ACL 기능 사용 (권장)';
$lang['i_superuser']           = '슈퍼 유저';
$lang['i_problems']            = '설치하는 동안 아래와 같은 문제가 발생했습니다. 문제를 해결한 후 설치를 계속하세요.';
$lang['i_modified']            = '보안 상의 이유로 이 스크립트는 수정되지 않은 새 Dokuwiki 설치에서만 동작됩니다.
다운로드한 압축 패키지를 다시 설치하거나 <a href="http://dokuwiki.org/install">DokuWiki 설치 과정</a>을 참고해서 설치하세요.';
$lang['i_funcna']              = '<code>%s</code> PHP 함수의 사용이 불가능합니다. 호스트 제공자가 어떤 이유에서인지 막아 놓았을지 모릅니다.';
$lang['i_phpver']              = 'PHP <code>%s</code> 버전은 필요한 <code>%s</code> 버전보다 오래되었습니다. PHP를 업그레이드할 필요가 있습니다.';
$lang['i_permfail']            = 'DokuWiki는 <code>%s</code>에 쓰기 가능 권한이 없습니다. 먼저 이 디렉토리에 쓰기 권한이 설정되어야 합니다!';
$lang['i_confexists']          = '<code>%s</code>(은)는 이미 존재합니다';
$lang['i_writeerr']            = '<code>%s</code>(을)를 만들 수 없습니다. 먼저 디렉토리/파일 권한을 확인하고 파일을 수동으로 만드세요.';
$lang['i_badhash']             = 'dokuwiki.php를 인식할 수 없거나 원본 파일이 아닙니다 (해시=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - 올바르지 않거나 빈 값입니다';
$lang['i_success']             = '환경 설정이 성공적으로 끝났습니다. 지금 install.php를 지워도 상관없습니다. <a href="doku.php?id=wiki:welcome">새 DokuWiki</a>로 들어갑니다.';
$lang['i_failure']             = '환경 설정 파일에 쓰는 도중에 오류가 발생했습니다. <a href="doku.php?id=wiki:welcome">새 DokuWiki</a>를 사용하기 전에 수동으로 문제를 해결해야 합니다.';
$lang['i_policy']              = '초기 ACL 정책';
$lang['i_pol0']                = '열린 위키 (누구나 읽기, 쓰기, 올리기가 가능합니다)';
$lang['i_pol1']                = '공개 위키 (누구나 읽을 수 있지만, 등록된 사용자만 쓰기와 올리기가 가능합니다)';
$lang['i_pol2']                = '닫힌 위키 (등록된 사용자만 읽기, 쓰기, 올리기가 가능합니다)';
$lang['i_retry']               = '다시 시도';
$lang['i_license']             = '내용을 배포하기 위한 라이선스를 선택하세요:';
$lang['i_license_none']        = '라이선스 정보를 보여주지 않습니다';
$lang['i_pop_field']           = 'DokuWiki 경험을 개선하는 데 도움을 주세요:';
$lang['i_pop_label']           = '한 달에 한 번씩, DokuWiki 개발자에게 익명의 사용 데이터를 보냅니다';
$lang['recent_global']         = '<b>%s</b> 이름공간을 구독 중입니다. <a href="%s">전체 위키의 최근 바뀜도 볼 수</a> 있습니다.';
$lang['years']                 = '%d년 전';
$lang['months']                = '%d개월 전';
$lang['weeks']                 = '%d주 전';
$lang['days']                  = '%d일 전';
$lang['hours']                 = '%d시간 전';
$lang['minutes']               = '%d분 전';
$lang['seconds']               = '%d초 전';
$lang['wordblock']             = '차단 문구(스팸 문구)를 포함하고 있어서 저장하지 않았습니다.';
$lang['media_uploadtab']       = '올리기';
$lang['media_searchtab']       = '찾기';
$lang['media_file']            = '파일';
$lang['media_viewtab']         = '보기';
$lang['media_edittab']         = '수정';
$lang['media_historytab']      = '역사';
$lang['media_list_thumbs']     = '섬네일';
$lang['media_list_rows']       = '목록';
$lang['media_sort_name']       = '이름';
$lang['media_sort_date']       = '날짜';
$lang['media_namespaces']      = '이름공간 선택';
$lang['media_files']           = '%s에 있는 파일';
$lang['media_upload']          = '%s에 올리기';
$lang['media_search']          = '%s 찾기';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s (%s에 있음)';
$lang['media_edit']            = '%s 편집';
$lang['media_history']         = '%s 바뀜 내역';
$lang['media_meta_edited']     = '메타데이터가 수정됨';
$lang['media_perm_read']       = '이 파일을 읽을 권한이 없습니다.';
$lang['media_perm_upload']     = '파일을 올릴 권한이 없습니다.';
$lang['media_update']          = '새 판 올리기';
$lang['media_restore']         = '이 판으로 되돌리기';
